@@ -10,19 +10,26 @@
 
 #include <resources/AbstractResource.h>
 
+#include "FlatpakPermission.h"
 #include "flatpak-helper.h"
 
 #include <AppStreamQt/component.h>
 
+#include <QAbstractItemModel>
 #include <QPixmap>
 
 class AddonList;
 class FlatpakBackend;
+class FlatpakSource;
+
 class FlatpakResource : public AbstractResource
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList topObjects MEMBER m_objects CONSTANT)
+    Q_PROPERTY(QStringList topObjects MEMBER s_objects CONSTANT)
+    Q_PROPERTY(QStringList objects MEMBER s_bottomObjects CONSTANT)
     Q_PROPERTY(QString attentionText READ attentionText CONSTANT)
+    Q_PROPERTY(QString dataLocation READ dataLocation CONSTANT)
+    Q_PROPERTY(bool hasDataButUninstalled READ hasDataButUninstalled NOTIFY hasDataButUninstalledChanged)
 public:
     explicit FlatpakResource(const AppStream::Component &component, FlatpakInstallation *installation, FlatpakBackend *parent);
 
@@ -149,7 +156,7 @@ public:
     void setPropertyState(PropertyKind kind, PropertyState state);
     void setResourceFile(const QUrl &url);
     void setRuntime(const QString &runtime);
-    void setState(State state);
+    void setState(State state, bool shouldEmit = true);
     void setType(ResourceType type);
     void setResourceLocation(const QUrl &location)
     {
@@ -163,16 +170,32 @@ public:
     void updateFromAppStream();
     void setArch(const QString &arch);
     QString attentionText() const;
+    QString dataLocation() const;
+    bool hasDataButUninstalled() const;
     void setAvailableVersion(const QString &version)
     {
         m_availableVersion = version;
     }
+    Q_INVOKABLE QAbstractListModel *permissionsModel();
+
+    void setTemporarySource(const QSharedPointer<FlatpakSource> &temp)
+    {
+        m_temp = temp;
+    }
+    QSharedPointer<FlatpakSource> temporarySource() const
+    {
+        return m_temp;
+    }
+
+    Q_INVOKABLE void clearUserData();
 
 Q_SIGNALS:
+    void hasDataButUninstalledChanged();
     void propertyStateChanged(FlatpakResource::PropertyKind kind, FlatpakResource::PropertyState state);
 
 private:
     void setCommit(const QString &commit);
+    void loadPermissions();
 
     const AppStream::Component m_appdata;
     FlatpakResource::Id m_id;
@@ -193,7 +216,10 @@ private:
     QString m_origin;
     QString m_availableVersion;
     FlatpakResource::ResourceType m_type = DesktopApp;
-    static const QStringList m_objects;
+    QSharedPointer<FlatpakSource> m_temp;
+    QVector<FlatpakPermission> m_permissions;
+    static const QStringList s_objects;
+    static const QStringList s_bottomObjects;
 };
 
 inline uint qHash(const FlatpakResource::Id &key)
