@@ -104,8 +104,8 @@ void PackageKitNotifier::checkOfflineUpdates()
         const QString errorDetails = group.readEntry("ErrorDetails");
 
         auto *notification = new KNotification(QStringLiteral("OfflineUpdateFailed"), KNotification::Persistent);
-        notification->setIconName(QStringLiteral("error"));
-        notification->setTitle(i18n("Offline Updates"));
+        notification->setIconName(QStringLiteral("dialog-error"));
+        notification->setTitle(i18n("Failed Offline Update"));
         notification->setText(i18np("Failed to update %1 package\n%2", "Failed to update %1 packages\n%2", packages.count(), errorDetails));
         notification->setActions(QStringList{i18nc("@action:button", "Open Discover"), i18nc("@action:button", "Repair System")});
         notification->setComponentName(QStringLiteral("discoverabstractnotifier"));
@@ -114,7 +114,15 @@ void PackageKitNotifier::checkOfflineUpdates()
             QProcess::startDetached(QStringLiteral("plasma-discover"), QStringList());
         });
         connect(notification, &KNotification::action2Activated, this, [this]() {
+            qInfo() << "Repairing system";
             auto trans = PackageKit::Daemon::global()->repairSystem();
+            KNotification::event(QStringLiteral("OfflineUpdateRepairStarted"),
+                                 i18n("Repairing failed offline update"),
+                                 {},
+                                 {},
+                                 KNotification::CloseOnTimeout,
+                                 QStringLiteral("org.kde.discovernotifier"));
+
             connect(trans, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error /*error*/, const QString &details) {
                 KNotification::event(QStringLiteral("OfflineUpdateRepairFailed"),
                                      i18n("Repair Failed"),
@@ -127,6 +135,13 @@ void PackageKitNotifier::checkOfflineUpdates()
                 qInfo() << "repair finished!" << status << runtime;
                 if (status == PackageKit::Transaction::ExitSuccess) {
                     PackageKit::Daemon::global()->offline()->clearResults();
+
+                    KNotification::event(QStringLiteral("OfflineUpdateRepairSuccessful"),
+                                         i18n("Repaired Successfully"),
+                                         {},
+                                         {},
+                                         KNotification::CloseOnTimeout,
+                                         QStringLiteral("org.kde.discovernotifier"));
                 }
             });
         });
